@@ -1,6 +1,6 @@
 package POE::Filter::IRCv3;
-$POE::Filter::IRCv3::VERSION = '1.001001';
-use strict; use warnings FATAL => 'all';
+$POE::Filter::IRCv3::VERSION = '1.002001';
+use strict; use warnings;
 
 use Carp;
 
@@ -24,7 +24,6 @@ sub SPCHR    () { "\x20" }
 our %CharToEscapedTag = (
   ';'  => '\:',
   ' '  => '\s',
-  "\0" => '\0',
   "\\" => '\\',
   "\r" => '\r',
   "\n" => '\n',
@@ -460,4 +459,10 @@ L<POE::Filter::Stackable>
 
 L<IRC::Toolkit>
 
+There are also some similar IRC parsing implementations in other languages.
+
+JavaScript: L<< https://github.com/expr/irc-message >>
+
+Rust: L<< https://github.com/TyOverby/irc-message >>
+
 =cut
